Index: src/fl_font_xft.cxx
===================================================================
--- src/fl_font_xft.cxx	(revision 5528)
+++ src/fl_font_xft.cxx	(working copy)
@@ -145,7 +145,7 @@
 		     XFT_PIXEL_SIZE, XftTypeDouble, (double)fl_size_,
 		     core ? XFT_CORE : 0, XftTypeBool, true,
 		     XFT_RENDER, XftTypeBool, false,
-		     0);
+		     (void *)0);
 }
 
 Fl_FontSize::Fl_FontSize(const char* name) {
Index: src/Fl_x.cxx
===================================================================
--- src/Fl_x.cxx	(revision 5528)
+++ src/Fl_x.cxx	(working copy)
@@ -367,16 +367,57 @@
   XCloseDisplay(fl_display);
 }
 
-int Fl::h() {
+static int fl_workarea_xywh[4] = { -1, -1, -1, -1 };
+
+static void fl_init_workarea() {
   fl_open_display();
-  return DisplayHeight(fl_display,fl_screen);
+
+  Atom _NET_WORKAREA = XInternAtom(fl_display, "_NET_WORKAREA", 0);
+  Atom actual;
+  unsigned long count, remaining;
+  int format;
+  unsigned *xywh;
+
+  if (XGetWindowProperty(fl_display, RootWindow(fl_display, fl_screen),
+                         _NET_WORKAREA, 0, 4 * sizeof(unsigned), False,
+			 XA_CARDINAL, &actual, &format, &count, &remaining,
+			 (unsigned char **)&xywh))
+  {
+    fl_workarea_xywh[0] = 0;
+    fl_workarea_xywh[1] = 0;
+    fl_workarea_xywh[2] = DisplayWidth(fl_display, fl_screen);
+    fl_workarea_xywh[3] = DisplayHeight(fl_display, fl_screen);
+  }
+  else
+  {
+    fl_workarea_xywh[0] = (int)xywh[0];
+    fl_workarea_xywh[1] = (int)xywh[1];
+    fl_workarea_xywh[2] = (int)xywh[2];
+    fl_workarea_xywh[3] = (int)xywh[3];
+    XFree(xywh);
+  }
 }
 
+int Fl::x() {
+  if (fl_workarea_xywh[0] < 0) fl_init_workarea();
+  return fl_workarea_xywh[0];
+}
+
+int Fl::y() {
+  if (fl_workarea_xywh[0] < 0) fl_init_workarea();
+  return fl_workarea_xywh[1];
+}
+
 int Fl::w() {
-  fl_open_display();
-  return DisplayWidth(fl_display,fl_screen);
+  if (fl_workarea_xywh[0] < 0) fl_init_workarea();
+  return fl_workarea_xywh[2];
 }
 
+int Fl::h() {
+  if (fl_workarea_xywh[0] < 0) fl_init_workarea();
+  return fl_workarea_xywh[3];
+}
+
 void Fl::get_mouse(int &xx, int &yy) {
   fl_open_display();
   Window root = RootWindow(fl_display, fl_screen);
Index: FL/Fl.H
===================================================================
--- FL/Fl.H	(revision 5528)
+++ FL/Fl.H	(working copy)
@@ -3,7 +3,7 @@
 //
 // Main header file for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2005 by Bill Spitzak and others.
+// Copyright 1998-2006 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -194,13 +194,8 @@
   static void paste(Fl_Widget &receiver);
 
   // screen size:
-#if defined(WIN32) || defined(__APPLE__)
   static int x();
   static int y();
-#else
-  static int x() {return 0;}
-  static int y() {return 0;}
-#endif /* WIN32 || __APPLE__ */
   static int w();
   static int h();
 
